@@ -42,6 +42,7 @@ def open_dataset(path, **kwargs):
 def merge_datasets(datasets, **kwargs):
     # type: (T.Sequence[xr.Dataset], T.Any) -> T.List[xr.Dataset]
     merged = []  # type: T.List[xr.Dataset]
+    first = []  # type: T.List[xr.Dataset]
     for ds in datasets:
         ds.attrs.pop("history", None)
         for i, o in enumerate(merged):
@@ -55,6 +56,19 @@ def merge_datasets(datasets, **kwargs):
                     pass
         else:
             merged.append(ds)
+            first.append(ds)
+
+    # Add the important coordinate encoding fields from the first found, to the merged:
+    preserve_encoding_fields = ["source", "units", "calendar", "dtype"]
+    for i, o in enumerate(first):
+        for var in o.coords:
+            out_encoding = {
+                key: o[var].encoding[key]
+                for key in preserve_encoding_fields
+                if key in o[var].encoding
+            }
+            merged[i][var].encoding.update(out_encoding)
+
     return merged
 
 
@@ -82,7 +96,7 @@ def open_variable_datasets(path, backend_kwargs={}, **kwargs):
         for key in ["filter_by_keys", "indexpath"]
         if key in backend_kwargs
     }
-    errors = backend_kwargs.get("grib_errors", "warn")
+    errors = backend_kwargs.get("errors", "warn")
     stream = messages.FileStream(path, errors=errors)
     index = open_fileindex(stream, computed_keys=cfmessage.COMPUTED_KEYS, **fileindex_kwargs)
     datasets = []  # type: T.List[xr.Dataset]
